@@ -1,4 +1,4 @@
 #' This is a look up table data for internal use only.
 #' @docType data
 #' @keywords internal look up data
-"datalms"
+"datalms5_19"
